import { APIFunction, Data, ParamType } from "../main";
import { FunctionToken, TemporalToken } from "./Compiler";
interface ParseOptions {
    reverse?: boolean;
    comments?: boolean;
    data: Data;
    debug?: boolean;
}
/**
 * Check if the given token is a valid string token.
 * @param token - Token to be validated.
 * @returns {boolean}
 */
export declare function isStringToken(token: any): token is TemporalToken;
export declare function isFunctionToken(token: any): token is FunctionToken;
export declare class Interpreter {
    /**
     * Parses easy-api.ts code.
     * @param code Code to parse.
     * @param options Parse extra options.
     */
    run(code: string, options: ParseOptions): Promise<Data<true>>;
    /**
     * Handles the a function output.
     * @param output - The function output to be parsed.
     * @param definition - Function definition.
     * @returns {true}
     */
    static handleOutput(output: string, definition: APIFunction): true;
    /**
     * Parses an string text to its native type.
     * @param type - Parameter type to parse to.
     * @param thing - Thing to be parsed.
     * @param token - Function source.
     * @param args - Extra arguments.
     * @returns {any}
     */
    static parse(type: ParamType, thing: string, token: FunctionToken, ...args: string[]): any;
    /**
     * Parses the given string as boolean.
     * @param bool - The string to be parsed.
     * @param token - Function source.
     * @returns {boolean}
     */
    static parseBoolean(bool: string, token: FunctionToken): boolean;
    /**
     * Parses the given string as big integer.
     * @param bigLike - The string to be parsed.
     * @param token - Function source.
     * @returns {bigint}
     */
    static parseBigInt(bigLike: string, token: FunctionToken): bigint;
    /**
     * Parses the given string as JavaScript date.
     * @param token - Function source.
     * @param date - The string to be parsed.
     * @returns {Date}
     */
    static parseDate(token: FunctionToken, date?: string): Date;
    /**
     * Parses the given string as JSON object.
     * @param entries - The string to be parsed.
     * @param token - Function source.
     * @returns {Record<unknown, unknown>}
     */
    static parseJSON(entries: string, token: FunctionToken): any;
    /**
     * Parses a list into a JavaScript array.
     * @param list - The string to be parsed.
     * @param separator - List element separator.
     * @param token - Function source.
     * @returns {string[]}
     */
    static parseList(list: string, separator: string, token: FunctionToken): string[];
    /**
     * Parses the given string as number.
     * @param num - The string to be parsed.
     * @param token - Function source.
     * @returns {number}
     */
    static parseNumber(num: string, token: FunctionToken): number;
    /**
     * Parses the given string as time number.
     * @param time - Time string to be parsed.
     * @param token - Function source.
     * @returns {number}
     */
    static parseTime(time: string, token: FunctionToken): number;
}
export {};
